==> qtjambi-xmlpatterns-debuginfo-macos-5.15.17.jar: sources/QtJambiXmlPatterns/QXmlNodeModelIndex_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXmlPatterns/qabstractxmlnodemodel.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlNodeModelIndex(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlNodeModelIndex")
    QXmlNodeModelIndex *_ptr = reinterpret_cast<QXmlNodeModelIndex *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlNodeModelIndex()
void __qt_construct_QXmlNodeModelIndex_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlNodeModelIndex()")
    Q_UNUSED(__java_arguments)
    QXmlNodeModelIndex *__qt_this = new(__qtjambi_ptr) QXmlNodeModelIndex();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QXmlNodeModelIndex(QXmlNodeModelIndex)
void __qt_construct_QXmlNodeModelIndex_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlNodeModelIndex(QXmlNodeModelIndex)")
    jobject other0 = __java_arguments[0].l;
    const QXmlNodeModelIndex& __qt_other0 = qtjambi_cast<const QXmlNodeModelIndex& >(__jni_env, other0);
    QXmlNodeModelIndex *__qt_this = new(__qtjambi_ptr) QXmlNodeModelIndex(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QXmlNodeModelIndex
void __qt_destruct_QXmlNodeModelIndex(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlNodeModelIndex")
    reinterpret_cast<QXmlNodeModelIndex*>(ptr)->~QXmlNodeModelIndex();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlNodeModelIndex::QXmlNodeModelIndex()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_initialize_1native__Lio_qt_xmlpatterns_QXmlNodeModelIndex_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlNodeModelIndex::QXmlNodeModelIndex()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlNodeModelIndex_0, sizeof(QXmlNodeModelIndex), typeid(QXmlNodeModelIndex), false, &deleter_QXmlNodeModelIndex, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNodeModelIndex::QXmlNodeModelIndex(QXmlNodeModelIndex)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_initialize_1native__Lio_qt_xmlpatterns_QXmlNodeModelIndex_2Lio_qt_xmlpatterns_QXmlNodeModelIndex_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlNodeModelIndex::QXmlNodeModelIndex(QXmlNodeModelIndex)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlNodeModelIndex_1, sizeof(QXmlNodeModelIndex), typeid(QXmlNodeModelIndex), false, &deleter_QXmlNodeModelIndex, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNodeModelIndex::additionalData()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_additionalData_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::additionalData()const", __qt_this)
        qint64 __qt_return_value = __qt_this->additionalData();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNodeModelIndex::data()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_data_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::data()const", __qt_this)
        qint64 __qt_return_value = __qt_this->data();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNodeModelIndex::isNull()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_isNull_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::isNull()const", __qt_this)
        __java_return_value = __qt_this->isNull();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNodeModelIndex::model()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_model_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::model()const", __qt_this)
        const QAbstractXmlNodeModel* __qt_return_value = __qt_this->model();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNodeModelIndex::operator=(QXmlNodeModelIndex)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_assign_1native_1cref_1QXmlNodeModelIndex__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::operator=(QXmlNodeModelIndex)", __qt_this)
        const QXmlNodeModelIndex& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QXmlNodeModelIndex>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNodeModelIndex::operator==(QXmlNodeModelIndex)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_operator_1equal_1native_1cref_1QXmlNodeModelIndex_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::operator==(QXmlNodeModelIndex)const", __qt_this)
        const QXmlNodeModelIndex& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QXmlNodeModelIndex>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QXmlNodeModelIndex(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QXmlNodeModelIndex>("QXmlNodeModelIndex", "io/qt/xmlpatterns/QXmlNodeModelIndex");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QXmlNodeModelIndex, {
        ConstructorInfo(&__qt_construct_QXmlNodeModelIndex_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QXmlNodeModelIndex_1, "Lio/qt/xmlpatterns/QXmlNodeModelIndex;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlNodeModelIndex);
    registerMetaType<QXmlNodeModelIndex>("QXmlNodeModelIndex");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QXmlNodeModelIndex::DocumentOrder>("QXmlNodeModelIndex::DocumentOrder", "io/qt/xmlpatterns/QXmlNodeModelIndex$DocumentOrder");
    registerEnumTypeInfo<QXmlNodeModelIndex::NodeKind>("QXmlNodeModelIndex::NodeKind", "io/qt/xmlpatterns/QXmlNodeModelIndex$NodeKind");
// END: enums and flags
}

==> qtjambi-xmlpatterns-debuginfo-macos-5.15.18.jar: sources/QtJambiXmlPatterns/QXmlNodeModelIndex_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXmlPatterns/qabstractxmlnodemodel.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QXmlNodeModelIndex(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QXmlNodeModelIndex")
    QXmlNodeModelIndex *_ptr = reinterpret_cast<QXmlNodeModelIndex *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QXmlNodeModelIndex()
void __qt_construct_QXmlNodeModelIndex_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlNodeModelIndex()")
    Q_UNUSED(__java_arguments)
    QXmlNodeModelIndex *__qt_this = new(__qtjambi_ptr) QXmlNodeModelIndex();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QXmlNodeModelIndex(QXmlNodeModelIndex)
void __qt_construct_QXmlNodeModelIndex_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QXmlNodeModelIndex(QXmlNodeModelIndex)")
    jobject other0 = __java_arguments[0].l;
    const QXmlNodeModelIndex& __qt_other0 = qtjambi_cast<const QXmlNodeModelIndex& >(__jni_env, other0);
    QXmlNodeModelIndex *__qt_this = new(__qtjambi_ptr) QXmlNodeModelIndex(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QXmlNodeModelIndex
void __qt_destruct_QXmlNodeModelIndex(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QXmlNodeModelIndex")
    reinterpret_cast<QXmlNodeModelIndex*>(ptr)->~QXmlNodeModelIndex();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QXmlNodeModelIndex::QXmlNodeModelIndex()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_initialize_1native__Lio_qt_xmlpatterns_QXmlNodeModelIndex_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlNodeModelIndex::QXmlNodeModelIndex()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlNodeModelIndex_0, sizeof(QXmlNodeModelIndex), typeid(QXmlNodeModelIndex), false, &deleter_QXmlNodeModelIndex, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNodeModelIndex::QXmlNodeModelIndex(QXmlNodeModelIndex)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_initialize_1native__Lio_qt_xmlpatterns_QXmlNodeModelIndex_2Lio_qt_xmlpatterns_QXmlNodeModelIndex_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QXmlNodeModelIndex::QXmlNodeModelIndex(QXmlNodeModelIndex)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QXmlNodeModelIndex_1, sizeof(QXmlNodeModelIndex), typeid(QXmlNodeModelIndex), false, &deleter_QXmlNodeModelIndex, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNodeModelIndex::additionalData()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_additionalData_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::additionalData()const", __qt_this)
        qint64 __qt_return_value = __qt_this->additionalData();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNodeModelIndex::data()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_data_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::data()const", __qt_this)
        qint64 __qt_return_value = __qt_this->data();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNodeModelIndex::isNull()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_isNull_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::isNull()const", __qt_this)
        __java_return_value = __qt_this->isNull();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNodeModelIndex::model()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_model_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::model()const", __qt_this)
        const QAbstractXmlNodeModel* __qt_return_value = __qt_this->model();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QXmlNodeModelIndex::operator=(QXmlNodeModelIndex)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_assign_1native_1cref_1QXmlNodeModelIndex__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::operator=(QXmlNodeModelIndex)", __qt_this)
        const QXmlNodeModelIndex& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QXmlNodeModelIndex>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QXmlNodeModelIndex::operator==(QXmlNodeModelIndex)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_equals_1native_1cref_1QXmlNodeModelIndex_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QXmlNodeModelIndex::operator==(QXmlNodeModelIndex)const", __qt_this)
        const QXmlNodeModelIndex& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QXmlNodeModelIndex>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xmlpatterns_QXmlNodeModelIndex_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QXmlNodeModelIndex *__qt_this = QtJambiAPI::objectFromNativeId<QXmlNodeModelIndex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QXmlNodeModelIndex(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QXmlNodeModelIndex>("QXmlNodeModelIndex", "io/qt/xmlpatterns/QXmlNodeModelIndex");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QXmlNodeModelIndex, {
        ConstructorInfo(&__qt_construct_QXmlNodeModelIndex_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QXmlNodeModelIndex_1, "Lio/qt/xmlpatterns/QXmlNodeModelIndex;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QXmlNodeModelIndex);
    registerMetaType<QXmlNodeModelIndex>("QXmlNodeModelIndex");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QXmlNodeModelIndex::DocumentOrder>("QXmlNodeModelIndex::DocumentOrder", "io/qt/xmlpatterns/QXmlNodeModelIndex$DocumentOrder");
    registerEnumTypeInfo<QXmlNodeModelIndex::NodeKind>("QXmlNodeModelIndex::NodeKind", "io/qt/xmlpatterns/QXmlNodeModelIndex$NodeKind");
// END: enums and flags
}
